==> ace_5.4.2.1.0.orig.tar.gz: ACE_wrappers/TAO/tao/IORInterceptor/IORInterceptor_Adapter_Factory_Impl.cpp <==
// IORInterceptor_Adapter_Factory_Impl.cpp,v 1.2 2003/07/28 14:19:42 parsons Exp

#include "IORInterceptor_Adapter_Factory_Impl.h"
#include "tao/ORB_Core.h"

ACE_RCSID (IORInterceptor,
           IORInterceptor_Adapter_Factory_Impl,
           "IORInterceptor_Adapter_Factory_Impl.cpp,v 1.2 2003/07/28 14:19:42 parsons Exp")

TAO_IORInterceptor_Adapter_Factory_Impl::~TAO_IORInterceptor_Adapter_Factory_Impl (void)
{
}

TAO_IORInterceptor_Adapter * TAO_IORInterceptor_Adapter_Factory_Impl::create (
    ACE_ENV_SINGLE_ARG_DECL_NOT_USED
  )
  ACE_THROW_SPEC ((CORBA::SystemException))
{
  TAO_IORInterceptor_Adapter_Impl * new_iorinterceptor_adapter;
  ACE_NEW_RETURN (new_iorinterceptor_adapter,
                  TAO_IORInterceptor_Adapter_Impl,
                  0);
  return new_iorinterceptor_adapter;
}


// *********************************************************************

// Initialization and registration of dynamic service object.

int
TAO_IORInterceptor_Adapter_Factory_Impl::Initializer (void)
{
  TAO_ORB_Core::iorinterceptor_adapter_factory_name (
      "Concrete_IORInterceptor_Adapter_Factory"
    );

  return
    ACE_Service_Config::process_directive (
        ace_svc_desc_TAO_IORInterceptor_Adapter_Factory_Impl
      );
}

ACE_STATIC_SVC_DEFINE (
    TAO_IORInterceptor_Adapter_Factory_Impl,
    ACE_TEXT ("Concrete_IORInterceptor_Adapter_Factory"),
    ACE_SVC_OBJ_T,
    &ACE_SVC_NAME (TAO_IORInterceptor_Adapter_Factory_Impl),
    ACE_Service_Type::DELETE_THIS | ACE_Service_Type::DELETE_OBJ,
    0
  )

ACE_FACTORY_DEFINE (TAO_IORInterceptor, TAO_IORInterceptor_Adapter_Factory_Impl)

==> ace_5.4.7.orig.tar.gz: ACE_wrappers/TAO/tao/IORInterceptor/IORInterceptor_Adapter_Factory_Impl.cpp <==
// IORInterceptor_Adapter_Factory_Impl.cpp,v 1.4 2004/11/28 17:47:42 bala Exp

#include "IORInterceptor_Adapter_Factory_Impl.h"
#include "IORInterceptor_Adapter_Impl.h"

#include "tao/ORB_Core.h"

ACE_RCSID (IORInterceptor,
           IORInterceptor_Adapter_Factory_Impl,
           "IORInterceptor_Adapter_Factory_Impl.cpp,v 1.4 2004/11/28 17:47:42 bala Exp")

TAO_IORInterceptor_Adapter_Factory_Impl::~TAO_IORInterceptor_Adapter_Factory_Impl (void)
{
}

TAO_IORInterceptor_Adapter *
TAO_IORInterceptor_Adapter_Factory_Impl::create (ACE_ENV_SINGLE_ARG_DECL)
  ACE_THROW_SPEC ((CORBA::SystemException))
{
  TAO_IORInterceptor_Adapter_Impl *nia = 0;
  ACE_NEW_THROW_EX (nia,
                    TAO_IORInterceptor_Adapter_Impl (),
                    CORBA::NO_MEMORY ());

  return nia;
}


// *********************************************************************

// Initialization and registration of dynamic service object.

int
TAO_IORInterceptor_Adapter_Factory_Impl::Initializer (void)
{
  TAO_ORB_Core::iorinterceptor_adapter_factory_name (
      "Concrete_IORInterceptor_Adapter_Factory"
    );

  return
    ACE_Service_Config::process_directive (
        ace_svc_desc_TAO_IORInterceptor_Adapter_Factory_Impl
      );
}

ACE_STATIC_SVC_DEFINE (
    TAO_IORInterceptor_Adapter_Factory_Impl,
    ACE_TEXT ("Concrete_IORInterceptor_Adapter_Factory"),
    ACE_SVC_OBJ_T,
    &ACE_SVC_NAME (TAO_IORInterceptor_Adapter_Factory_Impl),
    ACE_Service_Type::DELETE_THIS | ACE_Service_Type::DELETE_OBJ,
    0
  )

ACE_FACTORY_DEFINE (TAO_IORInterceptor, TAO_IORInterceptor_Adapter_Factory_Impl)
